pub fn unconfigured_provider(provider_name: &str) -> Box<dyn LlmProvider>Expand description
Create an unconfigured provider that returns an error when called. Used when a provider is not properly configured.
pub fn unconfigured_provider(provider_name: &str) -> Box<dyn LlmProvider>Create an unconfigured provider that returns an error when called. Used when a provider is not properly configured.