pub struct UnconfiguredProvider {
pub provider_name: String,
}Expand description
A provider that returns an error when no real provider is configured. Used when config is missing or invalid.
Fields
provider_name: StringTrait Implementations
Sourceimpl LlmProvider for UnconfiguredProvider
impl LlmProvider for UnconfiguredProvider
Sourcefn call<'life0, 'life1, 'async_trait>(
&'life0 self,
_prompt: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<String, AppError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
UnconfiguredProvider: 'async_trait,
fn call<'life0, 'life1, 'async_trait>(
&'life0 self,
_prompt: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<String, AppError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
UnconfiguredProvider: 'async_trait,
Call the LLM with a prompt and return the generated text.
For backward compatibility, this returns just the text.
Sourcefn call_with_usage<'life0, 'life1, 'async_trait>(
&'life0 self,
prompt: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<LlmCallResponse, AppError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn call_with_usage<'life0, 'life1, 'async_trait>(
&'life0 self,
prompt: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<LlmCallResponse, AppError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Call the LLM with a prompt and return the response with token usage.
Default implementation calls
call and returns unknown usage.Sourcefn call_with_tools<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
prompt: &'life1 str,
_tools: Option<&'life2 [Value]>,
) -> Pin<Box<dyn Future<Output = Result<LlmCallResponse, AppError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn call_with_tools<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
prompt: &'life1 str,
_tools: Option<&'life2 [Value]>,
) -> Pin<Box<dyn Future<Output = Result<LlmCallResponse, AppError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Call the LLM with a prompt and optional tool schemas. Read more